    const gridElement = document.getElementById('grid');
    let cols = 16; // Default to medium mode
    let rows = 16;
    let mineCount = 40;
    const grid = [];
    let revealedCount = 0;
    let gameOver = false;
    let firstClick = true; // Flag for first click

    // Initialize the grid with mines
    function init() {
      gridElement.style.gridTemplateColumns = `repeat(${cols}, 30px)`;
      gridElement.style.gap = '0px';

      for (let r = 0; r < rows; r++) {
        grid[r] = [];
        for (let c = 0; c < cols; c++) {
          grid[r][c] = { isMine: false, isRevealed: false, isFlagged: false, adjacent: 0 };
        }
      }

      draw(); // Draw the grid initially (without mines)
    }

    function countAdjacentMines(row, col) {
      let count = 0;
      for (let r = row - 1; r <= row + 1; r++) {
        for (let c = col - 1; c <= col + 1; c++) {
          if (r >= 0 && r < rows && c >= 0 && c < cols && grid[r][c].isMine) {
            count++;
          }
        }
      }
      return count;
    }

    function draw() {
      gridElement.innerHTML = '';
      for (let r = 0; r < rows; r++) {
        for (let c = 0; c < cols; c++) {
          const cell = document.createElement('div');
          cell.className = 'cell';
          cell.dataset.row = r;
          cell.dataset.col = c;

          if (grid[r][c].isRevealed) {
            if (grid[r][c].isMine) {
              cell.textContent = '💣';
              cell.style.backgroundColor = 'red';
            } else if (grid[r][c].adjacent > 0) {
              cell.textContent = grid[r][c].adjacent;
              cell.style.backgroundColor = 'lightgray';
            } else {
              cell.style.backgroundColor = 'lightgreen';
            }
          } else if (grid[r][c].isFlagged) {
            cell.textContent = '🚩';
          }

          cell.addEventListener('click', handleClick);
          cell.addEventListener('contextmenu', handleRightClick);
          gridElement.appendChild(cell);
        }
      }
    }

    function handleClick(event) {
      if (gameOver) return;
      const cell = event.target;
      const row = parseInt(cell.dataset.row);
      const col = parseInt(cell.dataset.col);

      if (firstClick) {
        firstClick = false;
        placeMines(row, col); // Place mines after the first click
        reveal(row, col); // Reveal the first clicked cell
      } else {
        reveal(row, col);
      }
    }

    function handleRightClick(event) {
      if (gameOver) return;
      event.preventDefault();
      const cell = event.target;
      const row = parseInt(cell.dataset.row);
      const col = parseInt(cell.dataset.col);
      toggleFlag(row, col);
    }

    function reveal(row, col) {
      if (grid[row][col].isRevealed || grid[row][col].isFlagged) return;

      grid[row][col].isRevealed = true;
      revealedCount++;

      if (grid[row][col].isMine) {
        gameOver = true;
        alert('Game Over! You hit a mine.');
        revealAllMines();
      } else if (grid[row][col].adjacent === 0) {
        for (let r = row - 1; r <= row + 1; r++) {
          for (let c = col - 1; c <= col + 1; c++) {
            if (r >= 0 && r < rows && c >= 0 && c < cols) {
              reveal(r, c);
            }
          }
        }
      }

      if (revealedCount === (rows * cols) - mineCount) {
        gameOver = true;
        alert('You Win!');
      }
      draw();
    }

    function toggleFlag(row, col) {
      grid[row][col].isFlagged = !grid[row][col].isFlagged;
      draw();
    }

    function revealAllMines() {
      for (let r = 0; r < rows; r++) {
        for (let c = 0; c < cols; c++) {
          if (grid[r][c].isMine) {
            grid[r][c].isRevealed = true;
          }
        }
      }
      draw();
    }

    // Event listeners for menu buttons
    document.getElementById('easy').addEventListener('click', () => {
      cols = 8;
      rows = 8;
      mineCount = 10;
      resetGame();
    });

    document.getElementById('medium').addEventListener('click', () => {
      cols = 16;
      rows = 16;
      mineCount = 40;
      resetGame();
    });

    document.getElementById('hard').addEventListener('click', () => {
      cols = 30;
      rows = 16;
      mineCount = 99;
      resetGame();
    });

    function resetGame() {
      gameOver = false;
      revealedCount = 0;
      firstClick = true; // Reset first click flag
      grid.length = 0; // Clear the grid array
      init();
    }

    // Place mines after the first click, avoiding the clicked cell and its adjacent cells
    function placeMines(row, col) {
      for (let i = 0; i < mineCount; i++) {
        let x, y;
        do {
          x = Math.floor(Math.random() * rows);
          y = Math.floor(Math.random() * cols);
        } while (grid[x][y].isMine || 
                 (Math.abs(x - row) <= 1 && Math.abs(y - col) <= 1)); // Avoid clicked cell and adjacent
        grid[x][y].isMine = true;
      }

      // Calculate adjacent mines
      for (let r = 0; r < rows; r++) {
        for (let c = 0; c < cols; c++) {
          if (grid[r][c].isMine) continue;
          grid[r][c].adjacent = countAdjacentMines(r, c);
        }
      }
    }

    // Start the game on medium mode by default
    init();
